<?php
/**
 * Plugin WPS secured
 *
 * @package   WPS
 * @author    wp-secured.com
 * @copyright Copyright © 2021
 */

declare(strict_types=1);

namespace WPSEC\Controllers;

defined( 'ABSPATH' ) || exit; // Exit if accessed directly.

if ( ! class_exists( 'WPSEC\Controllers\Users' ) ) {
    /**
     * Holds information about the users
     *
     * @since 1.0.0
     */
    class Users {

        /**
         * Holds the current user
         *
         * @since 1.0.0
         *
         * @var mixed
         */
        private static $loggedUsers = null;

        /**
         * Returns the currently logged users
         *
         * @since 1.0.0
         *
         * @return array \WP_User
         */
        public static function getLoggedUsers() {
            if ( null === self::$loggedUsers ) {
                self::$loggedUsers = get_users(
                    [
                        'meta_key'     => 'session_tokens',
                        'meta_compare' => 'EXISTS',
                    ]
                );
            }

            return self::$loggedUsers;
        }

        /**
         * Wipes off all the user meta
         *
         * @return void
         *
         * @since 1.0.0
         */
        public static function deleteAllUserData() {
            global $wpdb;

            $wpdb->query(
                $wpdb->prepare(
                    "DELETE FROM $wpdb->usermeta
                    WHERE 1
                    AND meta_key LIKE %s",
                    [
                        '_wpsec%',
                    ]
                )
            );
        }
    }
}
