<?php
/**
 * Plugin WPS secured
 *
 * @package   WPS
 * @author    wp-secured.com
 * @copyright Copyright © 2021
 */

declare(strict_types=1);

namespace WPSEC\Helpers;

defined( 'ABSPATH' ) || exit; // Exit if accessed directly.

if ( ! class_exists( 'WPSEC\Helpers\MailHelper' ) ) {
    /**
     * Provides general functionalities for plugin mailing
     *
     * @since 1.0.0
     */
    class MailHelper {

        /**
         * Returns the email header
         *
         * @param string $headerText - text to be put in between h1 tags in the mail header.
         *
         * @return string
         *
         * @since 1.0.0
         */
        public static function getMailHeader( string $headerText = '' ): string {

            ob_start();
            WPHelper::getTemplatePart(
                'email-header',
                [
                    'emailHeading' => $headerText,
                ]
            );

            $header = ob_get_clean();

            return $header;
        }

        /**
         * Returns the global email footer
         *
         * @return string
         *
         * @since 1.0.0
         */
        public static function getMailFooter(): string {

            ob_start();
            WPHelper::getTemplatePart(
                'email-footer',
            );

            $footer = ob_get_clean();

            return $footer;
        }
    }
}
