<?php
/**
 * Plugin WPS secured
 *
 * @package   WPS
 * @author    wp-secured.com
 * @copyright Copyright © 2021
 */

declare(strict_types=1);

namespace WPSEC\Helpers;

defined( 'ABSPATH' ) || exit; // Exit if accessed directly.

use ZxcvbnPhp\Zxcvbn;

if ( ! class_exists( 'WPSEC\Helpers\ValidatePassword' ) ) {
    /**
     * Responsible for proper Password Validation
     */
    class ValidatePassword {

        /**
         * Valid password regular expression string
         *
         * @var string
         */
        private static $validRE = '/(?=.*[A-Z])(?=.*[a-z])(?=.*\d)(?=.*[!\"#$%&\'\(\'\)* ,\-.\/\:;<=>\?@\[\\\\\]\^_`\{\|\}~])[A-Za-z\d!\"#$%&\'\(\)* ,\-.\/\:;<=>\?@\[\\\\\]\^_`\{\|\}~\"]{16,}/m';

        /**
         * Validates string against password validation expression
         *
         * @param string $password provided password which must be validated.
         *
         * @return boolean
         */
        public static function validate( string $password ): bool {
            $retVal = false;

            if ( '' !== trim( $password ) ) {
                if ( 1 === \preg_match( self::$validRE, $password ) ) {
                    $retVal = true;
                }
            }
            return $retVal;
        }

        /**
         * Gets password strength score
         *
         * @param string $password Checks the strength of the password.
         *
         * @return integer
         */
        public static function checkPasswordStrengthScore( $password ): int {
            $zxcvbn = new Zxcvbn();

            $score = $zxcvbn->passwordStrength( $password );

            return $score['score'];
        }
    }
}
