<?php
/**
 * Plugin WPS secured
 *
 * @package   WPS
 * @author    wp-secured.com
 * @copyright Copyright © 2021
 */

declare(strict_types=1);

/**
 * Plugin WPS secured
 *
 * @package   WPS
 * @author    wp-secured.com
 * @copyright Copyright © 2021
 */

namespace WPSEC\Views;

use WPSEC\Controllers\Modules\{
    Login,
    LoginAttempts,
    RememberMe,
    TwoFASettings,
    XMLRPCprevents,
};
use WPSEC\Helpers\Information\ModuleInformation;
use WPSEC\Secured;

defined( 'ABSPATH' ) || exit; // Exit if accessed directly.

if ( ! class_exists( 'WPSEC\Views\AdminSettingsView' ) ) {
    /**
     * Class responsible for showing the setting in the admin section
     *
     * @since 1.0.0
     */
    class AdminSettingsView {

        /**
         * All the tabs values description, modules based
         *
         * @since 1.0.0
         *
         * @var array
         */
        private static $tabs = [
            'loginSettings'    => [
                'classCSS'      => '',
                'class'         => 'WPSEC\Views\SettingsTabs',
                'displayMethod' => 'loginSettingsTab',
            ],
            'attemptsSettings' => [
                'class'         => 'WPSEC\Views\SettingsTabs',
                'displayMethod' => 'attemptsSettingsTab',
            ],
            '2faSettings'      => [
                'class'         => 'WPSEC\Views\SettingsTabs',
                'displayMethod' => 'twofaSettingsTab',
            ],
            'rememberMe'       => [
                'class'         => 'WPSEC\Views\SettingsTabs',
                'displayMethod' => 'rememberMeTab',
            ],
            'xmlrpc'           => [
                'class'         => 'WPSEC\Views\SettingsTabs',
                'displayMethod' => 'xmlRpcTab',
            ],
        ];

        /**
         * HTML elements ID prefix
         *
         * @since 1.0.0
         *
         * @var string
         */
        private static $prefix = 'snd';

        /**
         * Shows the admin page
         *
         * @since 1.0.0
         *
         * @return void
         */
        public static function adminSettings(): void {
            \WPSEC\Views\SettingsTabs::saveAllSettings();
            ?>
            <div class="wrap">
                <div id="icon-themes" class="icon32"></div>
                <h2><?php echo \esc_html( WPSEC_PLUGIN_SECURED_NAME ); ?></h2>
                <form class="<?php echo \esc_html( WPSEC_PLUGIN_SECURED_CSS_PREFIX ); ?>_form" method="post" action="" enctype="multipart/form-data">
                    <div id="poststuff">
                        <div id="post-body" class="metabox-holder columns-2">
                            <div id="post-body-content" style="position: relative;">
                            <?php self::displayTabs(); ?>
                            </div>
                            <div id="postbox-container-1" class="postbox-container">
                                <div class="meta-box-sortables ui-sortable">
                                    <div id="submitdiv" class="postbox">
                                        <h3 class="handle"><?php \esc_html_e( 'Information', 'secured-wp' ); ?></h3>
                                        <div class="inside">
                                            <div class="submitbox" id="submitpost">
                                                <div id="minor-publishing">
                                                    <div id="misc-publishing-actions">
                                                        <div class="misc-pub-section">
                                                            <?php echo \esc_html__( 'Provides Security for WP sites', 'secured-wp' ); ?>
                                                        </div>
                                                    </div>
                                                    <div id="misc-publishing-actions" class="clear">
                                                        <div class="misc-pub-section">
                                                            <strong><?php \esc_html_e( 'Version', 'secured-wp' ); ?>:</strong> <?php echo \esc_html( WPSEC_PLUGIN_SECURED_VERSION ); ?>
                                                        </div>
                                                        <div class="misc-pub-section">
                                                            <label for="<?php echo \esc_html( WPSEC_PLUGIN_SECURED_DELETE_DATA_VAR_NAME ); ?>">
                                                                <strong><?php echo \esc_html__( 'Delete data on plugin uninstall', 'secured-wp' ); ?></strong>
                                                                <input id="<?php echo \esc_html( WPSEC_PLUGIN_SECURED_DELETE_DATA_VAR_NAME ); ?>" name="<?php echo \esc_html( WPSEC_PLUGIN_SECURED_DELETE_DATA_VAR_NAME ); ?>" type="checkbox" value="true" <?php \checked( true, (bool) Secured::isDeleteDataEnabled() ); ?>>
                                                            </label>
                                                            <div><?php echo \esc_html__( 'That setting is global', 'secured-wp' ); ?></div>
                                                        </div>
                                                        <hr>
                                                        <div class="misc-pub-section">
                                                            <h4><?php echo \esc_html__( 'Modules Information', 'secured-wp' ); ?></h4>
                                                            <?php ModuleInformation::getInfo(); ?>
                                                        </div>
                                                    </div>
                                                    <div class="clear"></div>
                                                </div>
                                                <div id="major-publishing-actions">
                                                    <div id="publishing-action">
                                                        <input type="hidden" name="<?php echo \esc_attr( self::$prefix ); ?>_form_submit" value="submit" />
                                                        <?php
                                                        submit_button(
                                                            __( 'Save Changes', 'secured-wp' ),
                                                            'button button-primary',
                                                            '',
                                                            false
                                                        );
                                                        ?>
                                                    </div>
                                                    <div class="clear"></div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <div id="postbox-container-2" class="postbox-container">
                                <div class="submit">
                                    <?php
                                    \submit_button(
                                        __( 'Save Changes', 'secured-wp' ),
                                        'button button-primary',
                                        '',
                                        false
                                    );
                                    ?>
                                    <?php
                                    \submit_button(
                                        __( 'Restore Default Plugin Settings', 'secured-wp' ),
                                        'global-confirm',
                                        'WPSEC_restore_plugin_defaults',
                                        false
                                    );
                                    ?>
                                </div>
                            </div>
                        </div>
                    </div>
                    <?php \wp_nonce_field( WPSEC_PLUGIN_SECURED_BASENAME, 'WPSEC_settings_nonce_name' ); ?>
                </form>
                <script>
                    jQuery(".global-confirm").click( function() {
                        if( ! confirm( '<?php echo \esc_html__( 'Are you sure you want to restore the defaults? All settings will be overridden', 'secured-wp' ); ?>' ) ) {
                            event.preventDefault();
                        } 
                    });
                    jQuery(".module-confirm").click( function() {
                        if( ! confirm( '<?php echo \esc_html__( 'Are you sure you want to restore the defaults? All module settings will be overridden', 'secured-wp' ); ?>' ) ) {
                            event.preventDefault();
                        } 
                    });
                </script>
            </div>
            <?php
        }

        /**
         * Constructs tabs wrapper and call @displayTabsList for tabs and
         *
         * @displayTasContent for their content
         *
         * @since 1.0.0
         *
         * @return void
         */
        public static function displayTabs() {
            ?>
        <div id="<?php echo \esc_attr( WPSEC_PLUGIN_SECURED_CSS_PREFIX ); ?>_settings_tabs_wrapper">
            <ul id="<?php echo \esc_attr( WPSEC_PLUGIN_SECURED_CSS_PREFIX ); ?>_settings_tabs">
            <?php self::displayTabsList(); ?>
            </ul>
            <?php self::displayTabsContent(); ?>
            <div class="clear"></div>
            <input type="hidden" name="<?php echo \esc_attr( WPSEC_PLUGIN_SECURED_CSS_PREFIX ); ?>_active_tab" value="<?php echo ( ( isset( $_REQUEST[ WPSEC_PLUGIN_SECURED_CSS_PREFIX . '_active_tab' ] ) ) ? \esc_attr( \sanitize_text_field( \wp_unslash( $_REQUEST[ WPSEC_PLUGIN_SECURED_CSS_PREFIX . '_active_tab' ] ) ) ) : \esc_attr( key( self::$tabs ) ) ); ?>" />
        </div>
            <?php
        }

        /**
         * Displays all the settings tabs
         *
         * @since 1.0.0
         *
         * @return void
         */
        private static function displayTabsList() {

            $translatedLabels = [
                'loginSettings'    => Login::getModuleName(),
                'attemptsSettings' => LoginAttempts::getModuleName(),
                '2faSettings'      => TwoFASettings::getModuleName(),
                'rememberMe'       => RememberMe::getModuleName(),
                'xmlrpc'           => XMLRPCprevents::getModuleName(),
            ];

            foreach ( self::$tabs as $tabSlug => $data ) {

                $tabClass = WPSEC_PLUGIN_SECURED_CSS_PREFIX . '-tab-' . $tabSlug;
                $tabId    = WPSEC_PLUGIN_SECURED_CSS_PREFIX . '-tab-' . $tabSlug;

                if ( ! empty( $data['classCSS'] ) ) {
                    $tabClass .= ' ' . $data['classCSS'];
                }
                ?>
                <li id="<?php echo \esc_attr( $tabId ); ?>" class="<?php echo \esc_attr( $tabClass ); ?>" data-slug="<?php echo \esc_attr( $tabSlug ); ?>">
                    <a href="#<?php echo \esc_attr( self::$prefix . '_' . $tabSlug ); ?>_tab">
                        <span><?php echo \esc_html( $translatedLabels[ $tabSlug ] ); ?></span>
                    </a>
                </li>
                <?php
            }
        }

        /**
         * Displays all the tabs content
         *
         * @since 1.0.0
         *
         * @return void
         */
        private static function displayTabsContent() {
            foreach ( self::$tabs as $tabSlug => $data ) {
                ?>
                <div class="<?php echo \esc_attr( WPSEC_PLUGIN_SECURED_CSS_PREFIX ); ?>_tab ui-tabs-panel ui-widget-content ui-corner-bottom" id="<?php echo esc_attr( self::$prefix . '_' . $tabSlug . '_tab' ); ?>" aria-labelledby="ui-id-2" role="tabpanel" aria-hidden="false" style="display: block;">
                <?php

                if ( isset( $data['class'] ) ) {
                    $className = $data['class'];
                    $className::{$data['displayMethod']}();
                }

                ?>
                </div>
                <?php
            }
        }
    }
}
