<?php
/**
 * Plugin WPS secured
 *
 * @package   WPS
 * @author    wp-secured.com
 * @copyright Copyright © 2021
 */

declare(strict_types=1);

namespace WPSEC\Views;

defined( 'ABSPATH' ) || exit; // Exit if accessed directly.

use WPSEC\Secured;
use WPSEC\Controllers\Modules\{
    Login,
    LoginAttempts,
    RememberMe,
    TwoFASettings,
    XMLRPCprevents,
};

if ( ! class_exists( 'WPSEC\Views\SettingsTabs' ) ) {

    /**
     * Responsible for displaying the tabs settings and all the module settings
     *
     * @since 1.0.0
     */
    class SettingsTabs {

        /**
         * Setting are saved flag
         *
         * @since 1.0.0
         *
         * @var bool
         */
        public static $settingsSaved = null;

        /**
         * Displays login settings tab
         *
         * @since 1.0.0
         *
         * @return void
         */
        public static function loginSettingsTab() {
            ?>
            <h3><?php echo \esc_html__( 'Login redirection Settings', 'secured-wp' ); ?></h3>
            <div>
                <h4><input id="disable-login" type="checkbox" name="<?php echo \esc_attr( Login::getGlobalSettingsName() ); ?>" <?php \checked( true, (bool) Login::getGlobalSettingsValue() ); ?>>
                <label for="disable-login"><?php echo \esc_html__( 'Disable Login Redirection', 'secured-wp' ); ?></label></h4>
                <h5><?php echo \esc_html__( 'Description:', 'secured-wp' ); ?> <em><?php echo Login::getShortDescription(); // @codingStandardsIgnoreLine ?></em></h5>
            </div>
            <div><?php echo \esc_html__( 'These settings are blog related (multisite)', 'secured-wp' ); ?></div>
            <hr>
            <table class="form-table">
                <tbody>
                    <tr>
                        <th scope="row"><?php echo \esc_html__( 'New Login redirection slug', 'secured-wp' ); ?></th>
                            <td>
                                <label for="<?php echo \esc_attr( WPSEC_PLUGIN_SECURED_NEW_LOGIN_REDIRECT_VAR_NAME ); ?>">
                                    <input id="<?php echo \esc_attr( WPSEC_PLUGIN_SECURED_NEW_LOGIN_REDIRECT_VAR_NAME ); ?>" name="<?php echo \esc_attr( WPSEC_PLUGIN_SECURED_NEW_LOGIN_REDIRECT_VAR_NAME ); ?>" type="text" value="<?php echo \esc_attr( Login::newLoginSlug() ); ?>" placeholder="<?php echo \esc_html__( 'New login redirection slug', 'secured-wp' ); ?>">
                                </label>
                            </td>
                    </tr>
                    <tr>
                        <th scope="row"><?php echo \esc_html__( 'Redirect original login to', 'secured-wp' ); ?></th>
                        <td>
                            <label>
                                <input name="<?php echo \esc_attr( WPSEC_PLUGIN_SECURED_ORIGIN_LOGIN_REDIRECT_VAR_NAME ); ?>" type="text" value="<?php echo \esc_attr( Login::newRedirectSlug() ); ?>" placeholder="<?php echo \esc_html__( 'Redirect original login to', 'secured-wp' ); ?>">
                            </label>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row"><?php echo \esc_html__( 'Default Settings', 'secured-wp' ); ?></th>
                        <td>
                            <?php
                            \submit_button(
                                __( 'Restore Module Default Settings', 'secured-wp' ),
                                'global-confirm',
                                'WPSEC_restore_redirect_defaults',
                                false
                            );
                            ?>
                            <div><?php echo \esc_html__( 'This will restore module settings to defaults.', 'secured-wp' ); ?></div>
                        </td>
                    </tr>
                </tbody>
            </table>
                <?php
        }

        /**
         * Displays login attempts tab
         *
         * @since 1.0.0
         *
         * @return void
         */
        public static function attemptsSettingsTab() {
            $timeMins = LoginAttempts::getLockTimeMins();
            ?>
            <h3><?php echo \esc_html__( 'Login Attempts Settings', 'secured-wp' ); ?></h3>
            <div>
                <h4><input id="disable-login-attempts" type="checkbox" name="<?php echo \esc_attr( LoginAttempts::getGlobalSettingsName() ); ?>" <?php \checked( true, (bool) LoginAttempts::getGlobalSettingsValue() ); ?>>
                <label for="disable-login-attempts"><?php echo \esc_html__( 'Disable Login Attempts', 'secured-wp' ); ?></label></h4>
                <h5><?php echo \esc_html__( 'Description:', 'secured-wp' ); ?> <em><?php echo LoginAttempts::getShortDescription(); // @codingStandardsIgnoreLine ?></em></h5>
            </div>

            <div><?php echo \esc_html__( 'These settings are blog related (multisite)', 'secured-wp' ); ?></div>
            <hr>
            <table class="form-table">
                <tbody>
                    <tr>
                        <th scope="row"><?php echo \esc_html__( 'Login Attempts', 'secured-wp' ); ?></th>
                        <td>
                            <label for="<?php echo \esc_attr( WPSEC_PLUGIN_SECURED_LOGIN_ATTEMPTS_VAR_NAME ); ?>">
                                <input id="<?php echo \esc_attr( WPSEC_PLUGIN_SECURED_LOGIN_ATTEMPTS_VAR_NAME ); ?>" name="<?php echo \esc_attr( WPSEC_PLUGIN_SECURED_LOGIN_ATTEMPTS_VAR_NAME ); ?>" type="number" value="<?php echo \esc_attr( LoginAttempts::getAllowedAttempts() ); ?>"  placeholder="Login attempts count">
                            </label>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row"><?php echo \esc_html__( 'Lock time', 'secured-wp' ); ?></th>
                        <td>
                            <label>
                                <select name="<?php echo \esc_attr( WPSEC_PLUGIN_SECURED_LOGIN_ATTEMPTS_TIME_VAR_NAME ); ?>">
                                    <option value="15"<?php echo ( ( 15 === $timeMins ) ? "selected='selected'" : '' ); ?>>15</option>
                                    <option value="30"<?php echo ( ( 30 === $timeMins ) ? "selected='selected'" : '' ); ?>>30</option>
                                    <option value="45"<?php echo ( ( 45 === $timeMins ) ? "selected='selected'" : '' ); ?>>45</option>
                                    <option value="60"<?php echo ( ( 60 === $timeMins ) ? "selected='selected'" : '' ); ?>>60</option>
                                </select>
                                <span><?php echo \esc_html__( 'How many minutes to lock the user', 'secured-wp' ); ?></span>
                            </label>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row"><?php echo \esc_html__( 'Default Settings', 'secured-wp' ); ?></th>
                        <td>
                            <?php
                            \submit_button(
                                __( 'Restore Module Default Settings', 'secured-wp' ),
                                'global-confirm',
                                'WPSEC_restore_attempts_defaults',
                                false
                            );
                            ?>
                            <div><?php echo \esc_html__( 'This will restore module settings to defaults.', 'secured-wp' ); ?></div>
                        </td>
                    </tr>
                </tbody>
            </table>
            <?php
        }

        /**
         * Displays remember me tab
         *
         * @since 1.0.0
         *
         * @return void
         */
        public static function rememberMeTab() {
            $timeDays = RememberMe::getLockTimeDays();
            ?>
            <h3><?php echo \esc_html__( 'Remember Device Settings', 'secured-wp' ); ?></h3>
            <div>
                <h4><input id="disable-remember-me" type="checkbox" name="<?php echo \esc_attr( RememberMe::getGlobalSettingsName() ); ?>" <?php \checked( true, (bool) RememberMe::getGlobalSettingsValue() ); ?>>
                <label for="disable-remember-me"><?php echo \esc_html__( 'Disable Remember Devices', 'secured-wp' ); ?></label></h4>
                <h5><?php echo \esc_html__( 'Description:', 'secured-wp' ); ?> <em><?php echo RememberMe::getShortDescription(); // @codingStandardsIgnoreLine ?></em></h5>
            </div>

            <div><?php echo \esc_html__( 'These settings are blog related (multisite)', 'secured-wp' ); ?></div>
            <hr>
            <table class="form-table">
                <tbody>
                    <tr>
                        <th scope="row"><?php echo \esc_html__( 'Remember Device Time', 'secured-wp' ); ?></th>
                        <td>
                            <label>
                                <select name="<?php echo \esc_attr( WPSEC_PLUGIN_SECURED_REMEMBER_TIME_VAR_NAME ); ?>">
                                    <option value="5"<?php echo ( ( 5 === $timeDays ) ? "selected='selected'" : '' ); ?>>5</option>
                                    <option value="10"<?php echo ( ( 10 === $timeDays ) ? "selected='selected'" : '' ); ?>>10</option>
                                    <option value="15"<?php echo ( ( 15 === $timeDays ) ? "selected='selected'" : '' ); ?>>15</option>
                                    <option value="20"<?php echo ( ( 20 === $timeDays ) ? "selected='selected'" : '' ); ?>>20</option>
                                </select>
                                <span><?php echo \esc_html__( 'How many days remember device', 'secured-wp' ); ?></span>
                            </label>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row"><?php echo \esc_html__( 'Default Settings', 'secured-wp' ); ?></th>
                        <td>
                            <?php
                            \submit_button(
                                __( 'Restore Module Default Settings', 'secured-wp' ),
                                'global-confirm',
                                'WPSEC_restore_remember_defaults',
                                false
                            );
                            ?>
                            <div><?php echo \esc_html__( 'This will restore module settings to defaults.', 'secured-wp' ); ?></div>
                        </td>
                    </tr>
                </tbody>
            </table>
            <?php
        }

        /**
         * Displays 2FA tab
         *
         * @since 1.0.0
         *
         * @return void
         */
        public static function twofaSettingsTab() {
            ?>
            <h3><?php echo \esc_html__( '2FA Settings', 'secured-wp' ); ?></h3>
            <div>
                <h4><input id="disable-2fa" type="checkbox" name="<?php echo \esc_attr( TwoFASettings::getGlobalSettingsName() ); ?>" <?php \checked( true, (bool) TwoFASettings::getGlobalSettingsValue() ); ?>>
                <label for="disable-2fa"><?php echo \esc_html__( 'Disable 2FA', 'secured-wp' ); ?></label></h4>
                <h5><?php echo \esc_html__( 'Description:', 'secured-wp' ); ?> <em><?php echo TwoFASettings::getShortDescription(); // @codingStandardsIgnoreLine ?></em></h5>
            </div>

            <div><?php echo \esc_html__( 'These settings are blog related (multisite)', 'secured-wp' ); ?></div>
            <hr>
            <table class="form-table">
                <tbody>
                    <tr>
                        <th scope="row"><?php echo \esc_html__( 'TOTP ', 'secured-wp' ); ?></th>
                        <td>
                            <label for="<?php echo \esc_attr( WPSEC_PLUGIN_SECURED_2FA_TOTP_VAR_NAME ); ?>">
                                <input id="<?php echo \esc_attr( WPSEC_PLUGIN_SECURED_2FA_TOTP_VAR_NAME ); ?>" name="<?php echo \esc_attr( WPSEC_PLUGIN_SECURED_2FA_TOTP_VAR_NAME ); ?>" type="checkbox" value="true"  <?php \checked( true, (bool) TwoFASettings::isTotpEnabled() ); ?>>
                            </label>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row"><?php echo \esc_html__( 'Out of bond e-mail ', 'secured-wp' ); ?></th>
                        <td>
                            <label for="<?php echo \esc_attr( WPSEC_PLUGIN_SECURED_2FA_OOB_VAR_NAME ); ?>">
                                <input id="<?php echo \esc_attr( WPSEC_PLUGIN_SECURED_2FA_OOB_VAR_NAME ); ?>" name="<?php echo \esc_attr( WPSEC_PLUGIN_SECURED_2FA_OOB_VAR_NAME ); ?>" type="checkbox" value="true" <?php \checked( true, (bool) TwoFASettings::isOobEnabled() ); ?>>
                            </label>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row"><?php echo \esc_html__( 'Default Settings', 'secured-wp' ); ?></th>
                        <td>
                            <?php
                            \submit_button(
                                __( 'Restore Module Default Settings', 'secured-wp' ),
                                'global-confirm',
                                'WPSEC_restore_2fa_defaults',
                                false
                            );
                            ?>
                            <div><?php echo \esc_html__( 'This will restore plugin settings to defaults.', 'secured-wp' ); ?></div>
                        </td>
                    </tr>
                </tbody>
            </table>
            <?php
        }

        /**
         * Displays XML-RPC tab
         *
         * @since 1.0.0
         *
         * @return void
         */
        public static function xmlRpcTab() {
            ?>
            <h3><?php echo \esc_html__( 'XML-RPC Settings', 'secured-wp' ); ?></h3>
            <div>
                <h4><input id="disable-xmlrpc" type="checkbox" name="<?php echo \esc_attr( XMLRPCprevents::getGlobalSettingsName() ); ?>" <?php \checked( true, (bool) XMLRPCprevents::getGlobalSettingsValue() ); ?>>
                <label for="disable-xmlrpc"><?php echo \esc_html__( 'Enable XML-RPC', 'secured-wp' ); ?></label></h4>
                <h5><?php echo \esc_html__( 'Description:', 'secured-wp' ); ?> <em><?php echo XMLRPCprevents::getShortDescription(); // @codingStandardsIgnoreLine ?></em></h5>
            </div>

            <div><?php echo \esc_html__( 'These settings are blog related (multisite)', 'secured-wp' ); ?></div>
            <hr>
            <table class="form-table">
                <tbody>
                    <tr>
                        <th scope="row"><?php echo \esc_html__( 'Default Settings', 'secured-wp' ); ?></th>
                        <td>
                            <?php
                            \submit_button(
                                __( 'Restore Module Default Settings', 'secured-wp' ),
                                'global-confirm',
                                'WPSEC_restore_xmlrpc_defaults',
                                false
                            );
                            ?>
                            <div><?php echo \esc_html__( 'This will restore plugin settings to defaults.', 'secured-wp' ); ?></div>
                        </td>
                    </tr>
                </tbody>
            </table>
            <?php
        }

        /**
         * Performs save all settings
         *
         * @since 1.0.0
         *
         * @return void
         */
        public static function saveAllSettings() {
            if ( null === self::$settingsSaved ) {
                if (
                ! empty( $_POST ) &&
                \check_admin_referer( WPSEC_PLUGIN_SECURED_BASENAME, 'WPSEC_settings_nonce_name' )
                ) {
                    if ( isset( $_POST['WPSEC_restore_plugin_defaults'] ) ) {
                        Login::restoreDefaults();
                        LoginAttempts::restoreDefaults();
                        TwoFASettings::restoreDefaults();
                        RememberMe::restoreDefaults();
                        XMLRPCprevents::restoreDefaults();
                    } else {
                        self::saveLoginSettings();
                        self::saveAttemptsSettings();
                        self::saveTwofaSettings();
                        self::saveGlobalSettings();
                        self::saveRememberSettings();
                        self::saveXmlRpcSettings();
                    }
                }
                self::$settingsSaved = true;
            }
        }

        /**
         * Save values from settings tab
         *
         * Codding standards ignore lines note - nonce is processed before the method is called
         *
         * @since 1.0.0
         *
         * @return void
         */
        private static function saveLoginSettings() {

            Login::saveGlobalEnabled(
                (
                    (
                    isset( $_POST[ Login::getGlobalSettingsName() ] ) && ! empty( $_POST[ Login::getGlobalSettingsName() ] ) ?  // @codingStandardsIgnoreLine
                        \sanitize_text_field( \wp_unslash( $_POST[ Login::getGlobalSettingsName() ] ) ) :  // @codingStandardsIgnoreLine
                        ''
                    )
                )
            );

            if ( isset( $_POST['WPSEC_restore_redirect_defaults'] ) ) {  // @codingStandardsIgnoreLine
                Login::restoreDefaults();
            } else {
                if ( isset( $_POST[ WPSEC_PLUGIN_SECURED_NEW_LOGIN_REDIRECT_VAR_NAME ] ) ) {  // @codingStandardsIgnoreLine
                    Login::updateNewLoginSlug( \sanitize_text_field( \wp_unslash( $_POST[ WPSEC_PLUGIN_SECURED_NEW_LOGIN_REDIRECT_VAR_NAME ] ) ) ); // @codingStandardsIgnoreLine
                }

                if ( isset( $_POST[ WPSEC_PLUGIN_SECURED_ORIGIN_LOGIN_REDIRECT_VAR_NAME ] ) ) {  // @codingStandardsIgnoreLine
                    Login::updateNewRedirectSlug( \sanitize_text_field( \wp_unslash( $_POST[ WPSEC_PLUGIN_SECURED_ORIGIN_LOGIN_REDIRECT_VAR_NAME ] ) ) );  // @codingStandardsIgnoreLine
                }
            }
        }

        /**
         * Save values from attempts tab
         *
         * Codding standards ignore lines note - nonce is processed before the method is called
         *
         * @since 1.0.0
         *
         * @return void
         */
        private static function saveAttemptsSettings() {

            LoginAttempts::saveGlobalEnabled(
                (
                    (
                    isset( $_POST[ LoginAttempts::getGlobalSettingsName() ] ) && ! empty( $_POST[ LoginAttempts::getGlobalSettingsName() ] ) ?  // @codingStandardsIgnoreLine
                        \sanitize_text_field( \wp_unslash( $_POST[ LoginAttempts::getGlobalSettingsName() ] ) ) :  // @codingStandardsIgnoreLine
                        ''
                    )
                )
            );

            if ( isset( $_POST['WPSEC_restore_attempts_defaults'] ) ) {  // @codingStandardsIgnoreLine
                LoginAttempts::restoreDefaults();
            } else {
                if ( isset( $_POST[ WPSEC_PLUGIN_SECURED_LOGIN_ATTEMPTS_VAR_NAME ] ) ) {  // @codingStandardsIgnoreLine
                    LoginAttempts::setAllowedAttempts( $_POST[ WPSEC_PLUGIN_SECURED_LOGIN_ATTEMPTS_VAR_NAME ] );  // @codingStandardsIgnoreLine
                }

                if ( isset( $_POST[ WPSEC_PLUGIN_SECURED_LOGIN_ATTEMPTS_TIME_VAR_NAME ] ) ) {  // @codingStandardsIgnoreLine
                    LoginAttempts::setLockTimeMins( \sanitize_text_field( \wp_unslash( $_POST[ WPSEC_PLUGIN_SECURED_LOGIN_ATTEMPTS_TIME_VAR_NAME ] ) ) );  // @codingStandardsIgnoreLine
                }
            }
        }

        /**
         * Save values from remember tab
         *
         * Codding standards ignore lines note - nonce is processed before the method is called
         *
         * @since 1.0.0
         *
         * @return void
         */
        private static function saveRememberSettings() {

            RememberMe::saveGlobalEnabled(
                (
                    (
                    isset( $_POST[ RememberMe::getGlobalSettingsName() ] ) && ! empty( $_POST[ RememberMe::getGlobalSettingsName() ] ) ?  // @codingStandardsIgnoreLine
                        \sanitize_text_field( \wp_unslash( $_POST[ RememberMe::getGlobalSettingsName() ] ) ) :  // @codingStandardsIgnoreLine
                        ''
                    )
                )
            );

            if ( isset( $_POST['WPSEC_restore_remember_defaults'] ) ) {  // @codingStandardsIgnoreLine
                RememberMe::restoreDefaults();
            } else {
                if ( isset( $_POST[ WPSEC_PLUGIN_SECURED_REMEMBER_TIME_VAR_NAME ] ) ) {  // @codingStandardsIgnoreLine
                    RememberMe::setLockTimeDays( \sanitize_text_field( \wp_unslash( $_POST[ WPSEC_PLUGIN_SECURED_REMEMBER_TIME_VAR_NAME ] ) ) );  // @codingStandardsIgnoreLine
                }
            }
        }

        /**
         * Save values from 2fa settings tab
         *
         * Codding standards ignore lines note - nonce is processed before the method is called
         *
         * @since 1.0.0
         *
         * @return void
         */
        private static function saveTwofaSettings() {

            TwoFASettings::saveGlobalEnabled(
                (
                    (
                    isset( $_POST[ TwoFASettings::getGlobalSettingsName() ] ) && ! empty( $_POST[ TwoFASettings::getGlobalSettingsName() ] ) ?  // @codingStandardsIgnoreLine
                        \sanitize_text_field( \wp_unslash( $_POST[ TwoFASettings::getGlobalSettingsName() ] ) ) :  // @codingStandardsIgnoreLine
                        ''
                    )
                )
            );

            if ( isset( $_POST['WPSEC_restore_2fa_defaults'] ) ) {  // @codingStandardsIgnoreLine
                TwoFASettings::restoreDefaults();
            } else {
                if ( isset( $_POST[ WPSEC_PLUGIN_SECURED_2FA_TOTP_VAR_NAME ] ) ) {  // @codingStandardsIgnoreLine
                    TwoFASettings::setTotp( \sanitize_text_field( \wp_unslash( $_POST[ WPSEC_PLUGIN_SECURED_2FA_TOTP_VAR_NAME ] ) ) );  // @codingStandardsIgnoreLine
                } else {
                    TwoFASettings::setTotp( 'false' );
                }

                if ( isset( $_POST[ WPSEC_PLUGIN_SECURED_2FA_OOB_VAR_NAME ] ) ) {  // @codingStandardsIgnoreLine
                    TwoFASettings::setOob( \sanitize_text_field( \wp_unslash( $_POST[ WPSEC_PLUGIN_SECURED_2FA_OOB_VAR_NAME ] ) ) );  // @codingStandardsIgnoreLine
                } else {
                    TwoFASettings::setOob( 'false' );
                }
            }
        }

        /**
         * Save values from XML-RPC settings tab
         *
         * Codding standards ignore lines note - nonce is processed before the method is called
         *
         * @since 1.0.0
         *
         * @return void
         */
        private static function saveXmlRpcSettings() {

            XMLRPCprevents::saveGlobalEnabled(
                (
                    (
                    isset( $_POST[ XMLRPCprevents::getGlobalSettingsName() ] ) && ! empty( $_POST[ XMLRPCprevents::getGlobalSettingsName() ] ) ?  // @codingStandardsIgnoreLine
                        \sanitize_text_field( \wp_unslash( $_POST[ XMLRPCprevents::getGlobalSettingsName() ] ) ) :  // @codingStandardsIgnoreLine
                        ''
                    )
                )
            );

            if ( isset( $_POST['WPSEC_restore_xmlrpc_defaults'] ) ) {  // @codingStandardsIgnoreLine
                XMLRPCprevents::restoreDefaults();
            }
        }

        /**
         * Save values for the global plugin settings
         *
         * Codding standards ignore lines note - nonce is processed before the method is called
         *
         * @since 1.0.0
         *
         * @return void
         */
        private static function saveGlobalSettings() {
            if ( isset( $_POST[ WPSEC_PLUGIN_SECURED_DELETE_DATA_VAR_NAME ] ) ) {  // @codingStandardsIgnoreLine
                Secured::setDeleteOnUninstall( $_POST[ WPSEC_PLUGIN_SECURED_DELETE_DATA_VAR_NAME ] );  // @codingStandardsIgnoreLine
            } else {
                Secured::setDeleteOnUninstall( 'false' );
            }
        }
    }
}
