<?php
/**
 * Plugin WPS secured
 *
 * @package   WPS
 * @author    wp-secured.com
 * @copyright Copyright © 2021
 */

if ( ! defined( 'WP_UNINSTALL_PLUGIN' ) ) {
    exit;
}

use WPSEC\Secured;
use WPSEC\Helpers\WPHelper;
use WPSEC\Controllers\Users;
use WPSEC\Helpers\Information\ModuleInformation;

/**
 * Fired when the plugin is uninstalled.
 */
require __DIR__ . '/vendor/autoload.php';
require __DIR__ . '/constants.php';

/**
 * Removes the plugin option
 * Removes meta from all the users
 *
 * @return void
 */
function uninstallWPSSecured() {

    if ( Secured::isDeleteDataEnabled() ) {
        Users::deleteAllUserData();

        if ( function_exists( 'get_sites' ) && class_exists( 'WP_Site_Query' ) ) {
            $sites   = WPHelper::getSites();
            $modules = ModuleInformation::getModuleClasses();

            foreach ( $modules as $key => $module ) {
                if ( false !== strpos( $module, 'Base' ) ) {
                    unset( $modules[ $key ] );
                }
            }

            foreach ( $sites as $site ) {
                \switch_to_blog( $site->blog_id );

                foreach ( $modules as $module ) {
                    $module::deleteModuleData();
                }

                \restore_current_blog();
            }
        } else {
            $modules = ModuleInformation::getModuleClasses();

            foreach ( $modules as $key => $module ) {
                if ( false !== strpos( $module, 'Base' ) ) {
                    unset( $modules[ $key ] );
                }
            }

            foreach ( $modules as $module ) {
                $module::deleteModuleData();
            }
        }
        Secured::deleteData();
    }
}

uninstallWPSSecured();
